==> phpsysinfo_2.5.1.orig.tar.gz: phpsysinfo/includes/lang/no.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: no.php,v 1.14 2005/12/07 15:02:11 bigmichi1 Exp $

$text['title']          = 'Systeminformasjon';

$text['vitals']         = 'Vital Informasjon';
$text['hostname']       = 'Egentlige Tjenernavn';
$text['ip']             = 'IP-Adresse';
$text['kversion']       = 'Kernel Versjon';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Oppetid';
$text['users']          = 'Antall Brukere';
$text['loadavg']        = 'Gj.Snitt Belastning';

$text['hardware']       = 'Maskinvareinformasjon';
$text['numcpu']         = 'Prosessorer';
$text['cpumodel']       = 'Modell';
$text['cpuspeed']       = 'Brikke MHz';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Cache St&oslash;rrelse';
$text['bogomips']       = 'System Bogomips';

$text['pci']            = 'PCI Enheter';
$text['ide']            = 'IDE Enheter';
$text['scsi']           = 'SCSI Enheter';
$text['usb']            = 'USB Enheter';

$text['netusage']       = 'Nettverksbruk';
$text['device']         = 'Enhet';
$text['received']       = 'Mottatt';
$text['sent']           = 'Sendt';
$text['errors']         = 'Feil/Dropp';

$text['memusage']       = 'Minnebruk';
$text['phymem']         = 'Fysisk Minne';
$text['swap']           = 'Disk Swap';

$text['fs']             = 'Monterte Filsystemer';
$text['mount']          = 'Punkt';
$text['partition']      = 'Partisjon';

$text['percent']        = 'Brukt Kapasitet i Prosent';
$text['type']           = 'Type';
$text['free']           = 'Ledig';
$text['used']           = 'Brukt';
$text['size']           = 'St&oslash;rrelse';
$text['totals']         = 'Totalt';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'Ingen';

$text['capacity']       = 'Kapasitet';
  
$text['template']       = 'Mal';
$text['language']       = 'Spr&aring;k';
$text['submit']         = 'Endre';
$text['created']        = 'Generert av';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = 'dager';
$text['hours']          = 'timer';
$text['minutes']        = 'minutter';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= '- Kernel + applications';
$text['buffers']	= '- Buffers';
$text['cached']		= '- Cached';

?>

==> phpsysinfo_2.5.2.orig.tar.gz: phpsysinfo/includes/lang/no.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: no.php,v 1.17 2006/06/05 11:48:16 bigmichi1 Exp $

$text['title']          = 'Systeminformasjon';

$text['vitals']         = 'Vital Informasjon';
$text['hostname']       = 'Egentlige Tjenernavn';
$text['ip']             = 'IP-Adresse';
$text['kversion']       = 'Kernel Versjon';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Oppetid';
$text['users']          = 'Antall Brukere';
$text['loadavg']        = 'Gj.Snitt Belastning';

$text['hardware']       = 'Maskinvareinformasjon';
$text['numcpu']         = 'Prosessorer';
$text['cpumodel']       = 'Modell';
$text['cpuspeed']       = 'Brikke MHz';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Cache St&oslash;rrelse';
$text['bogomips']       = 'System Bogomips';

$text['pci']            = 'PCI Enheter';
$text['ide']            = 'IDE Enheter';
$text['scsi']           = 'SCSI Enheter';
$text['usb']            = 'USB Enheter';

$text['netusage']       = 'Nettverksbruk';
$text['device']         = 'Enhet';
$text['received']       = 'Mottatt';
$text['sent']           = 'Sendt';
$text['errors']         = 'Feil/Dropp';

$text['memusage']       = 'Minnebruk';
$text['phymem']         = 'Fysisk Minne';
$text['swap']           = 'Disk Swap';

$text['fs']             = 'Monterte Filsystemer';
$text['mount']          = 'Punkt';
$text['partition']      = 'Partisjon';

$text['percent']        = 'Brukt Kapasitet i Prosent';
$text['type']           = 'Type';
$text['free']           = 'Ledig';
$text['used']           = 'Brukt';
$text['size']           = 'St&oslash;rrelse';
$text['totals']         = 'Totalt';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'Ingen';

$text['capacity']       = 'Kapasitet';
  
$text['template']       = 'Mal';
$text['language']       = 'Spr&aring;k';
$text['submit']         = 'Endre';
$text['created']        = 'Generert av';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = 'dager';
$text['hours']          = 'timer';
$text['minutes']        = 'minutter';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degreeC']        = '&ordm;C';
$text['degreeF']        = '&ordm;F';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= 'Kernel + applications';
$text['buffers']	= 'Buffers';
$text['cached']		= 'Cached';

$text['connections']    = 'Established Network Connections';
?>
